@@ -1,15 +1,15 @@
 /*
  * THE NEMESIS PROJECT
- * Copyright (C) 1999, 2000 Mark Grimes <obecian@packetninja.net>
+ * Copyright (C) 1999, 2000, 2001 Mark Grimes <obecian@packetninja.net>
  *
  * nemesis-arp.h (ARP Packet Injector)
  *
  */
 
 
-#define TITLE "ARP Packet Injection -=- The NEMESIS Project -=- "
-#define VERSION "1.2"
-#define CODERS "Copyright (C) 1999, 2000 Mark Grimes <obecian@packetninja.net>"
+#define TITLE "ARP/RARP"
+#define VERSION "1.3"
+#define CODERS "Copyright (C) 1999, 2000, 2001 Mark Grimes <obecian@packetninja.net>"
 
 #include <stdio.h>
 #include <strings.h>
@@ -26,32 +26,29 @@
 #define OPTIMIZE 0
 #define PADDING 15
 
-u_int			enet_tmp[6];
+u_int           enet_tmp[6];
 u_long          source,		/* source address */
                 dest;		/* destination address */
 u_char         *payload,	/* payload pointer */
-				*pcap_pkt,	/* pcap packet */
-				*spkt_data,
-                enet_src[6],	/* source MAC address */
+               *pcap_pkt,	/* pcap packet */
+               *spkt_data, enet_src[6],	/* source MAC address */
                 enet_dst[6];	/* destination MAC address */
 
 int             got_link, got_payload;	/* sanity check */
-int				arptype;
+int             reply, ltype;	/* reply and arp/rarp type */
 
 int             payload_s;	/* payload size */
 
 char           *device;		/* network device */
-int 			link_type,
-				pcap_offset,
-				l3;
+int             link_type, pcap_offset, l3;
 
-struct 			libnet_link_int *l2;
+struct libnet_link_int *l2;
 
 int             verbose;	/* verbosity */
 
 int             buildarp();
 
-void						hexdump(char *, int);
+void            hexdump(char *, int);
 void            usage(char *);
 void            defaults();	/* defaults for packet fields */
 
