@@ -1,14 +1,14 @@
-/* 
- * THE NEMESIS PROJECT (c) obecian 1999, 2000
- * Copyright (C) 1999, 2000 Mark Grimes <obecian@packetninja.net>
- *
+/*
+ * THE NEMESIS PROJECT (c) obecian 1999, 2000 Copyright (C) 1999, 2000 Mark
+ * Grimes <obecian@packetninja.net>
+ * 
  * nemesis-ospf.h (OSPF Packet Injector)
- *
+ * 
  */
 
 
 #define TITLE "OSPF Packet Injection -=- The NEMESIS Project"
-#define VERSION "1.2"
+#define VERSION "1.3"
 #define CODERS "Copyright (C) 1999, 2000 Mark Grimes <obecian@packetninja.net>"
 
 #include <stdio.h>
@@ -28,16 +28,16 @@
 
 u_short         id,		/* IP id */
                 frag,		/* frag shit */
-				mtusize,	/* Max dgram length (DBD) */
-				num,		/* LSA_RTR num */
+                mtusize,	/* Max dgram length (DBD) */
+                num,		/* LSA_RTR num */
                 interval,	/* secs since last pkt sent */
-				rtr_flags,	/* LSA_RTR flags */
-				metric,		/* OSPF metric */
+                rtr_flags,	/* LSA_RTR flags */
+                metric,		/* OSPF metric */
                 ospf_age;	/* OSPF advertisement age */
 u_long          source,		/* source address */
                 dest,		/* destination address */
                 neighbor,	/* neighbor router */
-				as_fwd,		/* AS_EXT forward address */
+                as_fwd,		/* AS_EXT forward address */
                 addrid,		/* advertising router id */
                 addaid,		/* advertising area id */
                 router,		/* advertising router */
@@ -50,15 +50,15 @@ u_char          enet_src[6],	/* source MAC address */
                *payload,	/* payload pointer */
                 options[40],	/* IP options pointer */
                 priority,	/* OSPF priority */
-			 	exchange,	/* DBD exchange type */
-				rtrtype,	/* LSA_RTR type */
+                exchange,	/* DBD exchange type */
+                rtrtype,	/* LSA_RTR type */
                 ooptions;	/* OSPF options */
-u_int           enet_tmp[6], /* temp typecast array */
-				dead_int,	/* dead router interval in secs */
-				as_tag,		/* AS_EXT tag */
+u_int           enet_tmp[6],	/* temp typecast array */
+                dead_int,	/* dead router interval in secs */
+                as_tag,		/* AS_EXT tag */
                 seqnum,		/* seqnum for LSA */
-				bcastnum,	/* num of LSAs to bcast (LSU) */
-				rtrdata,	/* LSA_RTR router data */
+                bcastnum,	/* num of LSAs to bcast (LSU) */
+                rtrdata,	/* LSA_RTR router data */
                 rtrid;		/* router id for LSA */
 
 int             got_link, got_options, got_payload;	/* sanity checks */
@@ -71,17 +71,18 @@ char           *device;		/* network device */
 
 int             verbose;	/* verbosity */
 
-int             buildospf(); /* OSPF Protocol wrapper */
-int             build_hello(); /* Hello (discover/maintain neighbors) */
-int				build_dbd(); /* Database Description (summarize db contents) */
-int				build_lsr(); /* Link State Request (db d/l) */
-int				build_lsu(); /* Link State Update (db update) */
-int				build_lsartr(); /* Router Links Advertisment */
-int				build_lsanet(); /* Network Links Advertisement */
-int				build_lsasum_ip(); /* Summary Links Advertisement */
-int				build_lsaas();  /* AS Ext Link Advertisement */
+int             buildospf();	/* OSPF Protocol wrapper */
+int             build_hello();	/* Hello (discover/maintain neighbors) */
+int             build_dbd();	/* Database Description (summarize db
+				 * contents) */
+int             build_lsr();	/* Link State Request (db d/l) */
+int             build_lsu();	/* Link State Update (db update) */
+int             build_lsartr();	/* Router Links Advertisment */
+int             build_lsanet();	/* Network Links Advertisement */
+int             build_lsasum_ip();	/* Summary Links Advertisement */
+int             build_lsaas();	/* AS Ext Link Advertisement */
 
-void						hexdump(char *, int);
+void            hexdump(char *, int);
 void            usage(char *);
 void            defaults();	/* defaults for packet fields */
 
